package com.yaohun.levelreward;

import com.yaohun.levelreward.config.Config;
import com.yaohun.levelreward.data.PlayerData;
import com.yaohun.levelreward.gui.RewardGui;
import com.yaohun.levelreward.manage.PlayerManager;
import com.yaohun.levelreward.util.ToolsUtil;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.plugin.java.JavaPlugin;

/**
 * LevelReward 插件类，继承自 JavaPlugin
 * 该类主要用于处理玩家等级奖励的相关功能，包括插件的初始化、命令处理等
 */
public class LevelReward extends JavaPlugin {

    // LevelReward 插件的单例实例
    private static LevelReward instance;
    // 玩家管理器，用于管理玩家数据
    private static PlayerManager playerManager;

    /**
     * 插件启用时调用的方法
     * 用于初始化配置文件、玩家管理器以及注册事件监听器
     */
    @Override
    public void onEnable() {
        instance = this;
        saveDefaultConfig();
        Config.reloadConfig(this);
        playerManager = new PlayerManager();
        getServer().getPluginManager().registerEvents(new RewardGui(), this);
    }

    /**
     * 处理插件命令的方法
     * 根据不同的命令参数执行相应的操作，如打开奖励界面、重载配置文件等
     *
     * @param sender 命令发送者
     * @param cmd    被执行的命令对象
     * @param label  命令别名
     * @param args   命令参数数组
     * @return true 如果命令被成功处理，否则返回 false
     */
    @Override
    public boolean onCommand(CommandSender sender, Command cmd, String label, String[] args) {
        // 处理 "open" 命令，打开奖励界面
        if(args.length == 1 && "open".equalsIgnoreCase(args[0])){
            RewardGui.OpenGui((Player) sender);
            return true;
        }
        // 检查发送者是否是管理员
        if(!sender.isOp()) {
            return true;
        }
        // 显示帮助信息
        if (args.length == 0) {
            sender.sendMessage("");
            sender.sendMessage("§e------- ======= §6等级成长礼包 §e======= -------");
            sender.sendMessage("§2/"+label+" open §f- §2打开界面");
            sender.sendMessage("§2/"+label+" skull §f- §2查看头颅码");
            sender.sendMessage("§2/"+label+" reload §f- §2重载配置文件");
            sender.sendMessage("§2/"+label+" convert §f- §c转换旧版数据");
            sender.sendMessage("§e------- ======= §6等级成长礼包 §e======= -------");
            sender.sendMessage("");
            return true;
        }
        // 处理 "skull" 命令，查看头颅码
        if("skull".equalsIgnoreCase(args[0])){
            Player player = (Player) sender;
            ItemStack stack = player.getInventory().getItemInMainHand();
            sender.sendMessage("[查询头颅] Base64ID: "+ToolsUtil.getHandSkullBase64(stack));
            return true;
        }
        // 处理 "reload" 命令，重载配置文件
        if("reload".equalsIgnoreCase(args[0])){
            Config.reloadConfig(this);
            sender.sendMessage("[等级礼包] 配置文件已重载.");
            return true;
        }
        // 处理 "convert" 命令，转换旧版数据
        if("convert".equalsIgnoreCase(args[0])){
            ConfigurationSection section = getConfig().getConfigurationSection("ExpUpData");
            if(section == null) {
                return true;
            }
            int count = 0;
            for (String playerName : section.getKeys(false)){
                PlayerData playerData = new PlayerData(playerName);
                playerData.setRewardList(section.getStringList(playerName));
                playerData.savePlayerData();
                count++;
            }
            sender.sendMessage("[等级礼包] 数据转换 "+count+"名");
            return true;
        }
        return false;
    }

    /**
     * 获取 LevelReward 插件的单例实例
     *
     * @return LevelReward 插件的实例
     */
    public static LevelReward inst() {
        return instance;
    }

    /**
     * 获取玩家管理器
     *
     * @return 玩家管理器实例
     */
    public static PlayerManager getPlayerManager() {
        return playerManager;
    }
}

