package com.yaohun.levelreward.hook;

import com.yaohun.storyline.Storyline;
import com.yaohun.storyline.data.PlayerData;
import com.yaohun.storyline.manage.PlayerManager;
import org.bukkit.entity.Player;

/**
 * 任务故事线挂钩类
 * 用于检查玩家是否完成特定任务
 */
public class QuestStoryHook {

    /**
     * 检查玩家是否完成指定任务线
     * @param player 要检查的玩家对象
     * @return true表示已完成任务(当前任务ID>=17)，false表示未完成或玩家数据不存在
     */
    public static boolean isCompleteQuest(Player player){
        // 获取玩家名称用于查询数据
        String playerName = player.getName();

        // 从故事线系统获取玩家管理器
        PlayerManager playerManager = Storyline.getPlayerManager();

        // 获取玩家的任务数据
        PlayerData playerData = playerManager.getPlayerData(playerName);

        // 如果玩家数据不存在，返回未完成
        if(playerData == null){
            return false;
        }

        // 检查当前任务ID是否达到完成标准(17)
        if(playerData.getCurrentQuest() >= 17){
            return true;
        }

        // 不满足条件返回false
        return false;
    }
}
