package com.yaohun.levelreward.manage;

import com.yaohun.levelreward.data.PlayerData;
import org.bukkit.Bukkit;
import org.bukkit.entity.Player;

import java.util.HashMap;

// 玩家数据管理类，用于存储和管理玩家的数据
public class PlayerManager {

    // 存储玩家数据的哈希映射，键为玩家名称，值为玩家数据对象
    private final HashMap<String, PlayerData> playerDataMap = new HashMap<>();

    /**
     * 构造函数，初始化在线玩家的数据
     */
    public PlayerManager() {
        // 遍历当前在线的所有玩家
        for (Player player : Bukkit.getOnlinePlayers()) {
            // 获取玩家名称
            String playerName = player.getName();
            // 创建并存储玩家数据对象
            playerDataMap.put(playerName,new PlayerData(playerName));
        }
    }

    /**
     * 获取或创建玩家的数据
     * 如果玩家数据不存在，则创建新的玩家数据对象
     *
     * @param playerName 玩家名称
     * @return 玩家数据对象
     */
    public PlayerData getPlayerData(String playerName) {
        // 检查玩家数据是否存在
        if (!playerDataMap.containsKey(playerName)) {
            // 如果不存在，创建并存储新的玩家数据对象
            playerDataMap.put(playerName,new PlayerData(playerName));
        }
        // 返回玩家数据对象
        return playerDataMap.get(playerName);
    }
}