package com.yaohun.levelreward.util;

import com.mojang.authlib.GameProfile;
import com.mojang.authlib.properties.Property;
import com.yaohun.aurechargedata.api.RechargeAPI;
import com.yaohun.aurechargedata.util.TimeType;
import com.yaohun.levelreward.config.Config;
import com.yaohun.levelreward.data.PlayerData;
import com.yaohun.levelreward.data.RewardData;
import me.Demon.DemonPlugin.data.NbtItem;
import org.bukkit.Material;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;
import org.bukkit.inventory.meta.SkullMeta;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

/**
 * 根据玩家和奖励数据获取礼物包ItemStack
 * 此方法用于根据玩家的特定条件动态生成不同的礼物包每个礼物包都有一个独特的外观和属性
 *
 * @param player 玩家对象，用于获取玩家信息如名称和等级
 * @param rewardData 奖励数据对象，包含奖励所需等级和奖励具体内容等信息
 * @return 返回一个根据玩家和奖励数据定制的ItemStack对象
 */
public class StackUtil {

    public static ItemStack getGiftPack(Player player, RewardData rewardData){
        // 获取基础礼物包配置
        ItemStack stack = Config.getItemStack("LevelGiftPack");
        // 如果奖励包含“kejin”，则使用付费礼物包配置
        if(rewardData.getRewardKey().contains("kejin")){
            stack = Config.getItemStack("PayGiftPack");
        }
        // 设置物品类型和耐久值
        stack.setType(Material.SKULL_ITEM);
        stack.setDurability((short) 3);
        // 获取并设置物品的SkullMeta元数据
        SkullMeta meta = (SkullMeta) stack.getItemMeta();
        GameProfile profile = new GameProfile(UUID.randomUUID(), null);
        String base64 = rewardData.getBase64();
        profile.getProperties().put("textures", new Property("textures", base64));
        try {
            Field profileField = meta.getClass().getDeclaredField("profile");
            profileField.setAccessible(true);
            profileField.set(meta, profile);
        } catch (Exception e) {
            e.printStackTrace();
        }
        // 更新物品名称，用实际需要的等级替换占位符
        String itemName = meta.getDisplayName();
        meta.setDisplayName(itemName.replace("{level}",String.valueOf(rewardData.getNeedLevel())));
        // 更新物品的附带信息，根据不同的占位符替换相应的玩家和奖励信息
        List<String> lore = meta.getLore();
        List<String> newLore = new ArrayList<>();
        for (String line : lore) {
            if (line.contains("{coins}")) {
                newLore.add(line.replace("{coins}", String.valueOf(RechargeAPI.getRechargeData(player.getName(), TimeType.ANNUAL))));
            } else if (line.contains("{name}")) {
                newLore.add(line.replace("{name}", player.getName()));
            } else if (line.contains("{player_level}")) {
                newLore.add(line.replace("{player_level}", String.valueOf(player.getLevel())));
            } else if (line.contains("{rewardLore}")) {
                newLore.addAll(rewardData.getRewardList());
            } else {
                newLore.add(line);
            }
        }
        meta.setLore(newLore);
        stack.setItemMeta(meta);
        // 使用NBT技术存储额外的奖励信息到物品中
        NbtItem nbtItem = new NbtItem(stack);
        nbtItem.setString("rewardKey", rewardData.getRewardKey());
        nbtItem.setInteger("needLevel", rewardData.getNeedLevel());
        return nbtItem.getItem();
    }
}

